@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 # This Python file uses the following encoding: utf-8
 
-import settings
+from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
 # A path to a directory from witch walk down so you can choose your files.
