@@ -2,7 +2,7 @@
 # -*- coding:utf-8 -*-
 # This Python file uses the following encoding: utf-8
 
-VERSION = (0,4,7)
+VERSION = (0,4,9)
 APPLICATION_NAME = "Dynamic Link"
 VERSION_str = str(VERSION).strip('()').replace(',','.').replace(' ','')
 VERSION_INFO = """
@@ -10,7 +10,13 @@ Version: %s
 Modification date: 03.08.2011
 
 Hints:
-- 0.4.7 -   - Preesettings can now be overwrite in the presettings.py in the project
+
+
+- 0.4.9     Testet with Django 1.2 u. 1.3
+- 0.4.8.4   Some small changes
+- 0.4.8.3   Some small changes
+- 0.4.8     Runs now under Django 1.3
+- 0.4.7   - Preesettings can now be overwrite in the presettings.py in the project
             folder, or directly in the global settings.py, or in a file
             called dl_settings.py in the same directory as manage.py.
             - django-dynamic-link now runs with python below version 2.6
@@ -26,4 +32,4 @@ Hints:
 
 TODO:
     - write more unittests
-""" % (VERSION_str,)
+""" % (VERSION_str,)
\ No newline at end of file
